@@ -15,6 +15,8 @@
 #define IRQ_SCSI        2
 #define IRQ_TIMER       3
 #define IRQ_ETH         4
+#define IRQ_GETH	5
+#define IRQ_TGETH	6
 
 
 struct package {
@@ -78,6 +80,10 @@ struct interrupt {
 	
 
 	cpumask_t	numa_mask;
+	cpumask_t	allowed_mask;
+
+	/* user/driver provided for smarter balancing */
+	cpumask_t	node_mask;
 };
 
 
